CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_constants.h Source File

CCL

ccl_constants.h
Go to the documentation of this file.
1 #pragma once
2
3
4 #include "gsl/gsl_const_mksa.h"
5
6 //Spline types
7 #define A_SPLINE_TYPE gsl_interp_akima
8 #define K_SPLINE_TYPE gsl_interp_akima
9 #define M_SPLINE_TYPE gsl_interp_akima
10 #define D_SPLINE_TYPE gsl_interp_akima
11 #define PNL_SPLINE_TYPE gsl_interp2d_bicubic
12 #define PLIN_SPLINE_TYPE gsl_interp2d_bicubic
13
19 #define K_PIVOT 0.05
20
24 #define RHO_CRITICAL 2.7744948E11
25
29 #define CLIGHT_HMPC 2997.92458 //H0^-1 in Mpc/h
30
34 //#define GNEWT 6.6738e-11 //(from PDG 2013) in m^3/Kg/s^2
35 #define GNEWT 6.67428e-11 // CLASS VALUE
36
40 #define SOLAR_MASS 1.9885e30
41
45 #define MPC_TO_METER 3.08567758149e22
46
50 #define PC_TO_METER 3.08567758149e16
51
55 #define KBOLTZ GSL_CONST_MKSA_BOLTZMANN
56
60 #define STBOLTZ GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT
61
65 #define HPLANCK GSL_CONST_MKSA_PLANCKS_CONSTANT_H
66
70 #define CLIGHT GSL_CONST_MKSA_SPEED_OF_LIGHT
71
75 #define EV_IN_J GSL_CONST_MKSA_ELECTRON_VOLT
76
80 #define TNCDM 0.71611
81
82 //Precision parameters
86 #define EPSREL_DIST 1E-6
87
91 #define EPSREL_GROWTH 1E-6
92
96 #define EPSREL_DNDZ 1E-6
97
101 #define EPS_SCALEFAC_GROWTH 1E-6